@@ -5,11 +5,10 @@ use std::str::FromStr;
 
 use indexmap::IndexMap;
 use ref_cast::RefCast;
-use reqwest_retry::policies::ExponentialBackoff;
 use tracing::{debug, info};
 
 use uv_cache::Cache;
-use uv_client::{BaseClientBuilder, retries_from_env};
+use uv_client::BaseClientBuilder;
 use uv_pep440::{Prerelease, Version};
 use uv_platform::{Arch, Libc, Os, Platform};
 use uv_preview::Preview;
@@ -231,8 +230,7 @@ impl PythonInstallation {
 
         // Python downloads are performing their own retries to catch stream errors, disable the
         // default retries to avoid the middleware from performing uncontrolled retries.
-        let retry_policy =
-            ExponentialBackoff::builder().build_with_max_retries(retries_from_env()?);
+        let retry_policy = client_builder.retry_policy();
         let client = client_builder.clone().retries(0).build();
 
         info!("Fetching requested Python...");
@@ -462,7 +460,7 @@ impl PythonInstallationKey {
             "python{maj}.{min}{var}{exe}",
             maj = self.major,
             min = self.minor,
-            var = self.variant.suffix(),
+            var = self.variant.executable_suffix(),
             exe = std::env::consts::EXE_SUFFIX
         )
     }
@@ -472,7 +470,7 @@ impl PythonInstallationKey {
         format!(
             "python{maj}{var}{exe}",
             maj = self.major,
-            var = self.variant.suffix(),
+            var = self.variant.executable_suffix(),
             exe = std::env::consts::EXE_SUFFIX
         )
     }
@@ -481,7 +479,7 @@ impl PythonInstallationKey {
     pub fn executable_name(&self) -> String {
         format!(
             "python{var}{exe}",
-            var = self.variant.suffix(),
+            var = self.variant.executable_suffix(),
             exe = std::env::consts::EXE_SUFFIX
         )
     }
