@@ -6,11 +6,12 @@ use futures::StreamExt;
 use tokio::sync::Semaphore;
 use uv_cache::{Cache, Refresh};
 use uv_cache_info::Timestamp;
-use uv_client::RegistryClientBuilder;
-use uv_configuration::{Concurrency, DependencyGroups, Preview, TargetTriple};
+use uv_client::{BaseClientBuilder, RegistryClientBuilder};
+use uv_configuration::{Concurrency, DependencyGroups, TargetTriple};
 use uv_distribution_types::IndexCapabilities;
 use uv_normalize::DefaultGroups;
-use uv_pep508::PackageName;
+use uv_normalize::PackageName;
+use uv_preview::Preview;
 use uv_python::{PythonDownloads, PythonPreference, PythonRequest, PythonVersion};
 use uv_resolver::{PackageMap, TreeDisplay};
 use uv_scripts::Pep723Script;
@@ -28,14 +29,15 @@ use crate::commands::project::{
 use crate::commands::reporters::LatestVersionReporter;
 use crate::commands::{ExitStatus, diagnostics};
 use crate::printer::Printer;
-use crate::settings::{NetworkSettings, ResolverSettings};
+use crate::settings::LockCheck;
+use crate::settings::ResolverSettings;
 
 /// Run a command.
 #[allow(clippy::fn_params_excessive_bools)]
 pub(crate) async fn tree(
     project_dir: &Path,
     groups: DependencyGroups,
-    locked: bool,
+    lock_check: LockCheck,
     frozen: bool,
     universal: bool,
     depth: u8,
@@ -44,12 +46,13 @@ pub(crate) async fn tree(
     no_dedupe: bool,
     invert: bool,
     outdated: bool,
+    show_sizes: bool,
     python_version: Option<PythonVersion>,
     python_platform: Option<TargetTriple>,
     python: Option<String>,
     install_mirrors: PythonInstallMirrors,
     settings: ResolverSettings,
-    network_settings: &NetworkSettings,
+    client_builder: &BaseClientBuilder<'_>,
     script: Option<Pep723Script>,
     python_preference: PythonPreference,
     python_downloads: PythonDownloads,
@@ -78,8 +81,6 @@ pub(crate) async fn tree(
     };
     let groups = groups.with_defaults(default_groups);
 
-    let native_tls = network_settings.native_tls;
-
     // Find an interpreter for the project, unless `--frozen` and `--universal` are both set.
     let interpreter = if frozen && universal {
         None
@@ -88,7 +89,7 @@ pub(crate) async fn tree(
             LockTarget::Script(script) => ScriptInterpreter::discover(
                 script.into(),
                 python.as_deref().map(PythonRequest::parse),
-                network_settings,
+                client_builder,
                 python_preference,
                 python_downloads,
                 &install_mirrors,
@@ -106,7 +107,7 @@ pub(crate) async fn tree(
                 project_dir,
                 &groups,
                 python.as_deref().map(PythonRequest::parse),
-                network_settings,
+                client_builder,
                 python_preference,
                 python_downloads,
                 &install_mirrors,
@@ -125,8 +126,8 @@ pub(crate) async fn tree(
     // Determine the lock mode.
     let mode = if frozen {
         LockMode::Frozen
-    } else if locked {
-        LockMode::Locked(interpreter.as_ref().unwrap())
+    } else if let LockCheck::Enabled(lock_check) = lock_check {
+        LockMode::Locked(interpreter.as_ref().unwrap(), lock_check)
     } else if matches!(target, LockTarget::Script(_)) && !target.lock_path().is_file() {
         // If we're locking a script, avoid creating a lockfile if it doesn't already exist.
         LockMode::DryRun(interpreter.as_ref().unwrap())
@@ -141,7 +142,7 @@ pub(crate) async fn tree(
     let lock = match LockOperation::new(
         mode,
         &settings,
-        network_settings,
+        client_builder,
         &state,
         Box::new(DefaultResolveLogger),
         concurrency,
@@ -155,7 +156,7 @@ pub(crate) async fn tree(
     {
         Ok(result) => result.into_lock(),
         Err(ProjectError::Operation(err)) => {
-            return diagnostics::OperationDiagnostic::native_tls(native_tls)
+            return diagnostics::OperationDiagnostic::native_tls(client_builder.is_native_tls())
                 .report(err)
                 .map_or(Ok(ExitStatus::Failure), |err| Err(err.into()));
         }
@@ -201,8 +202,7 @@ pub(crate) async fn tree(
                 dependency_metadata: _,
                 config_setting: _,
                 config_settings_package: _,
-                no_build_isolation: _,
-                no_build_isolation_package: _,
+                build_isolation: _,
                 extra_build_dependencies: _,
                 extra_build_variables: _,
                 exclude_newer: _,
@@ -216,13 +216,10 @@ pub(crate) async fn tree(
 
             // Initialize the registry client.
             let client = RegistryClientBuilder::new(
+                client_builder.clone(),
                 cache.clone().with_refresh(Refresh::All(Timestamp::now())),
             )
-            .retries_from_env()?
-            .native_tls(network_settings.native_tls)
-            .connectivity(network_settings.connectivity)
-            .allow_insecure_host(network_settings.allow_insecure_host.clone())
-            .index_locations(index_locations)
+            .index_locations(index_locations.clone())
             .keyring(*keyring_provider)
             .build();
             let download_concurrency = Semaphore::new(concurrency.downloads);
@@ -283,6 +280,7 @@ pub(crate) async fn tree(
         &groups,
         no_dedupe,
         invert,
+        show_sizes,
     );
 
     print!("{tree}");
