@@ -6,6 +6,115 @@ use uv_static::EnvVars;
 
 use crate::common::{TestContext, uv_snapshot};
 
+#[test]
+#[cfg(feature = "native-auth")]
+fn add_package_native_auth_realm() -> Result<()> {
+    let context = TestContext::new("3.12").with_real_home();
+
+    // Clear state before the test
+    context
+        .auth_logout()
+        .arg("https://pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("public")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth")
+        .status()?;
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(indoc::indoc! { r#"
+        [project]
+        name = "foo"
+        version = "1.0.0"
+        requires-python = ">=3.11, <4"
+        dependencies = []
+        "#
+    })?;
+
+    // Try to add a package without credentials.
+    uv_snapshot!(context.add().arg("anyio").arg("--default-index").arg("https://public@pypi-proxy.fly.dev/basic-auth/simple")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: false
+    exit_code: 1
+    ----- stdout -----
+
+    ----- stderr -----
+      × No solution found when resolving dependencies:
+      ╰─▶ Because anyio was not found in the package registry and your project depends on anyio, we can conclude that your project's requirements are unsatisfiable.
+
+          hint: An index URL (https://pypi-proxy.fly.dev/basic-auth/simple) could not be queried due to a lack of valid authentication credentials (401 Unauthorized).
+      help: If you want to add the package regardless of the failed resolution, provide the `--frozen` flag to skip locking and syncing.
+    "
+    );
+
+    // Login to the domain
+    uv_snapshot!(context.auth_login()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("public")
+        .arg("--password")
+        .arg("heron")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Stored credentials for public@https://pypi-proxy.fly.dev/
+    "
+    );
+
+    // Try to add the original package without credentials again. This should use credentials
+    // storied in the system keyring.
+    uv_snapshot!(context.add().arg("anyio").arg("--default-index").arg("https://public@pypi-proxy.fly.dev/basic-auth/simple")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Resolved 4 packages in [TIME]
+    Prepared 3 packages in [TIME]
+    Installed 3 packages in [TIME]
+     + anyio==4.3.0
+     + idna==3.6
+     + sniffio==1.3.1
+    "
+    );
+
+    // Logout of the domain
+    uv_snapshot!(context.auth_logout()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("public")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Removed credentials for public@https://pypi-proxy.fly.dev/
+    "
+    );
+
+    // Authentication should fail again
+    uv_snapshot!(context.add().arg("iniconfig").arg("--default-index").arg("https://public@pypi-proxy.fly.dev/basic-auth/simple")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: false
+    exit_code: 1
+    ----- stdout -----
+
+    ----- stderr -----
+      × No solution found when resolving dependencies:
+      ╰─▶ Because iniconfig was not found in the package registry and your project depends on iniconfig, we can conclude that your project's requirements are unsatisfiable.
+
+          hint: An index URL (https://pypi-proxy.fly.dev/basic-auth/simple) could not be queried due to a lack of valid authentication credentials (401 Unauthorized).
+      help: If you want to add the package regardless of the failed resolution, provide the `--frozen` flag to skip locking and syncing.
+    "
+    );
+
+    Ok(())
+}
+
 #[test]
 #[cfg(feature = "native-auth")]
 fn add_package_native_auth() -> Result<()> {
@@ -68,16 +177,17 @@ fn add_package_native_auth() -> Result<()> {
     // credentials storied in the system keyring.
     uv_snapshot!(context.add().arg("anyio").arg("--default-index").arg("https://public@pypi-proxy.fly.dev/basic-auth/simple")
         .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
-    success: false
-    exit_code: 1
+    success: true
+    exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
-      × No solution found when resolving dependencies:
-      ╰─▶ Because anyio was not found in the package registry and your project depends on anyio, we can conclude that your project's requirements are unsatisfiable.
-
-          hint: An index URL (https://pypi-proxy.fly.dev/basic-auth/simple) could not be queried due to a lack of valid authentication credentials (401 Unauthorized).
-      help: If you want to add the package regardless of the failed resolution, provide the `--frozen` flag to skip locking and syncing.
+    Resolved 4 packages in [TIME]
+    Prepared 3 packages in [TIME]
+    Installed 3 packages in [TIME]
+     + anyio==4.3.0
+     + idna==3.6
+     + sniffio==1.3.1
     "
     );
 
@@ -178,12 +288,12 @@ fn token_native_auth() -> Result<()> {
         .arg("--username")
         .arg("public")
         .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
-    success: false
-    exit_code: 2
+    success: true
+    exit_code: 0
     ----- stdout -----
+    heron
 
     ----- stderr -----
-    error: Failed to fetch credentials for public@https://pypi-proxy.fly.dev/basic-auth/simple
     ");
 
     // Without the username
@@ -233,12 +343,12 @@ fn token_native_auth() -> Result<()> {
     uv_snapshot!(context.auth_token()
         .arg("https://pypi-proxy.fly.dev/basic-auth/simple")
         .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
-    success: false
-    exit_code: 2
+    success: true
+    exit_code: 0
     ----- stdout -----
+    heron
 
     ----- stderr -----
-    error: Failed to fetch credentials for https://pypi-proxy.fly.dev/basic-auth/simple
     ");
 
     context
@@ -252,12 +362,12 @@ fn token_native_auth() -> Result<()> {
     uv_snapshot!(context.auth_token()
         .arg("https://public@pypi-proxy.fly.dev/basic-auth/simple")
         .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
-    success: false
-    exit_code: 2
+    success: true
+    exit_code: 0
     ----- stdout -----
+    heron
 
     ----- stderr -----
-    error: Failed to fetch credentials for public@https://pypi-proxy.fly.dev/basic-auth/simple
     ");
 
     // Conflict between --username and URL username is rejected
@@ -277,6 +387,200 @@ fn token_native_auth() -> Result<()> {
     Ok(())
 }
 
+#[test]
+#[cfg(feature = "native-auth")]
+fn token_native_auth_realm() -> Result<()> {
+    let context = TestContext::new_with_versions(&[]).with_real_home();
+
+    // Clear state before the test
+    context
+        .auth_logout()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("public")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth")
+        .status()?;
+    context
+        .auth_logout()
+        .arg("https://pypi-proxy.fly.dev/basic-auth/simple")
+        .arg("--username")
+        .arg("public")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth")
+        .status()?;
+
+    // Without persisted credentials
+    uv_snapshot!(context.auth_token()
+        .arg("pypi-proxy.fly.dev")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    heron
+
+    ----- stderr -----
+    ");
+
+    // Without persisted credentials (with a username in the request)
+    uv_snapshot!(context.auth_token()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("public")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Failed to fetch credentials for public@https://pypi-proxy.fly.dev/
+    ");
+
+    // Login to the index
+    uv_snapshot!(context.auth_login()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("public")
+        .arg("--password")
+        .arg("heron")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Stored credentials for public@https://pypi-proxy.fly.dev/
+    "
+    );
+
+    // Show the credentials
+    uv_snapshot!(context.auth_token()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("public")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    heron
+
+    ----- stderr -----
+    ");
+
+    // Show the credentials for a child URL
+    uv_snapshot!(context.auth_token()
+        .arg("https://pypi-proxy.fly.dev/basic-auth/simple")
+        .arg("--username")
+        .arg("public")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    heron
+
+    ----- stderr -----
+    ");
+
+    // Without the username
+    uv_snapshot!(context.auth_token()
+        .arg("pypi-proxy.fly.dev")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    heron
+
+    ----- stderr -----
+    ");
+
+    // Without the username
+    uv_snapshot!(context.auth_token()
+        .arg("https://pypi-proxy.fly.dev/basic-auth/simple")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    heron
+
+    ----- stderr -----
+    ");
+
+    // With a mismatched username
+    // TODO(zanieb): Add a hint here if we can?
+    uv_snapshot!(context.auth_token()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("private")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Failed to fetch credentials for private@https://pypi-proxy.fly.dev/
+    ");
+
+    // With a mismatched port
+    uv_snapshot!(context.auth_token()
+        .arg("https://pypi-proxy.fly.dev:1000")
+        .arg("--username")
+        .arg("public")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Failed to fetch credentials for public@https://pypi-proxy.fly.dev:1000/
+    ");
+
+    // Login to the index with a token
+    uv_snapshot!(context.auth_login()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--token")
+        .arg("heron")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Stored credentials for https://pypi-proxy.fly.dev/
+    "
+    );
+
+    // Retrieve the token without a username
+    uv_snapshot!(context.auth_token()
+        .arg("pypi-proxy.fly.dev")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    heron
+
+    ----- stderr -----
+    ");
+
+    context
+        .auth_logout()
+        .arg("pypi-proxy.fly.dev")
+        .arg("--username")
+        .arg("public")
+        .status()?;
+
+    // Retrieve token using URL with embedded username (no --username needed)
+    uv_snapshot!(context.auth_token()
+        .arg("https://public@pypi-proxy.fly.dev/basic-auth/simple")
+        .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    heron
+
+    ----- stderr -----
+    ");
+
+    Ok(())
+}
+
 #[test]
 #[cfg(feature = "native-auth")]
 fn login_native_auth() -> Result<()> {
@@ -1546,12 +1850,12 @@ fn native_auth_prefix_match() -> Result<()> {
         .arg("--username")
         .arg("testuser")
         .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
-    success: false
-    exit_code: 2
+    success: true
+    exit_code: 0
     ----- stdout -----
+    testpass
 
     ----- stderr -----
-    error: Failed to fetch credentials for testuser@https://example.com/api/v1
     "
     );
 
@@ -1590,18 +1894,17 @@ fn native_auth_host_fallback() -> Result<()> {
     );
 
     // Should fallback to host-level matching
-    // TODO(zanieb): This is not working as intended
     uv_snapshot!(context.auth_token()
         .arg("https://example.com/any/path")
         .arg("--username")
         .arg("testuser")
         .env(EnvVars::UV_PREVIEW_FEATURES, "native-auth"), @r"
-    success: false
-    exit_code: 2
+    success: true
+    exit_code: 0
     ----- stdout -----
+    hostpass
 
     ----- stderr -----
-    error: Failed to fetch credentials for testuser@https://example.com/any/path
     "
     );
 
