@@ -3,6 +3,8 @@
 
 pub(crate) mod common;
 
+mod auth;
+
 mod branching_urls;
 
 #[cfg(all(feature = "python", feature = "pypi"))]
@@ -17,6 +19,9 @@ mod cache_clean;
 #[cfg(all(feature = "python", feature = "pypi"))]
 mod cache_prune;
 
+#[cfg(all(feature = "python", feature = "pypi"))]
+mod cache_size;
+
 #[cfg(all(feature = "python", feature = "pypi", feature = "test-ecosystem"))]
 mod ecosystem;
 
@@ -26,6 +31,9 @@ mod edit;
 #[cfg(all(feature = "python", feature = "pypi"))]
 mod export;
 
+#[cfg(all(feature = "python", feature = "pypi"))]
+mod format;
+
 mod help;
 
 #[cfg(all(feature = "python", feature = "pypi", feature = "git"))]
@@ -78,6 +86,9 @@ mod python_find;
 #[cfg(feature = "python")]
 mod python_list;
 
+#[cfg(all(feature = "python", feature = "pypi"))]
+mod python_module;
+
 #[cfg(feature = "python-managed")]
 mod python_install;
 
@@ -128,4 +139,5 @@ mod version;
 #[cfg(all(feature = "python", feature = "pypi"))]
 mod workflow;
 
+mod extract;
 mod workspace;
