@@ -280,7 +280,7 @@ fn python_list_unsupported_version() {
     ----- stdout -----
 
     ----- stderr -----
-    error: Invalid version request: Python <3.13 does not support free-threading but 3.12t was requested.
+    error: Invalid version request: Python <3.13 does not support free-threading but 3.12+freethreaded was requested.
     ");
 }
 
@@ -361,11 +361,11 @@ fn python_list_downloads() {
     // Instead, we choose a Python version where our available distributions are stable
 
     // Test the default display, which requires reverting the test context disabling Python downloads
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove("UV_PYTHON_DOWNLOADS"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
     success: true
     exit_code: 0
     ----- stdout -----
-    cpython-3.10.18-[PLATFORM]    <download available>
+    cpython-3.10.19-[PLATFORM]    <download available>
     pypy-3.10.16-[PLATFORM]       <download available>
     graalpy-3.10.0-[PLATFORM]     <download available>
 
@@ -373,10 +373,11 @@ fn python_list_downloads() {
     ");
 
     // Show patch versions
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--all-versions").env_remove("UV_PYTHON_DOWNLOADS"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--all-versions").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
     success: true
     exit_code: 0
     ----- stdout -----
+    cpython-3.10.19-[PLATFORM]    <download available>
     cpython-3.10.18-[PLATFORM]    <download available>
     cpython-3.10.17-[PLATFORM]    <download available>
     cpython-3.10.16-[PLATFORM]    <download available>
@@ -419,11 +420,11 @@ fn python_list_downloads_installed() {
     // Instead, we choose a Python version where our available distributions are stable
 
     // First, the download is shown as available
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove("UV_PYTHON_DOWNLOADS"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
     success: true
     exit_code: 0
     ----- stdout -----
-    cpython-3.10.18-[PLATFORM]    <download available>
+    cpython-3.10.19-[PLATFORM]    <download available>
     pypy-3.10.16-[PLATFORM]       <download available>
     graalpy-3.10.0-[PLATFORM]     <download available>
 
@@ -434,7 +435,7 @@ fn python_list_downloads_installed() {
     // the URL
 
     // But not if `--only-installed` is used
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--only-installed").env_remove("UV_PYTHON_DOWNLOADS"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--only-installed").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -446,11 +447,11 @@ fn python_list_downloads_installed() {
     context.python_install().arg("3.10").assert().success();
 
     // Then, it should be listed as installed instead of available
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove("UV_PYTHON_DOWNLOADS"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
     success: true
     exit_code: 0
     ----- stdout -----
-    cpython-3.10.18-[PLATFORM]    managed/cpython-3.10.18-[PLATFORM]/[INSTALL-BIN]/[PYTHON]
+    cpython-3.10.19-[PLATFORM]    managed/cpython-3.10.19-[PLATFORM]/[INSTALL-BIN]/[PYTHON]
     pypy-3.10.16-[PLATFORM]       <download available>
     graalpy-3.10.0-[PLATFORM]     <download available>
 
@@ -458,11 +459,11 @@ fn python_list_downloads_installed() {
     ");
 
     // But, the display should be reverted if `--only-downloads` is used
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--only-downloads").env_remove("UV_PYTHON_DOWNLOADS"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--only-downloads").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
     success: true
     exit_code: 0
     ----- stdout -----
-    cpython-3.10.18-[PLATFORM]    <download available>
+    cpython-3.10.19-[PLATFORM]    <download available>
     pypy-3.10.16-[PLATFORM]       <download available>
     graalpy-3.10.0-[PLATFORM]     <download available>
 
@@ -470,7 +471,7 @@ fn python_list_downloads_installed() {
     ");
 
     // And should not be shown if `--no-managed-python` is used
-    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--no-managed-python").env_remove("UV_PYTHON_DOWNLOADS"), @r"
+    uv_snapshot!(context.filters(), context.python_list().arg("3.10").arg("--no-managed-python").env_remove(EnvVars::UV_PYTHON_DOWNLOADS), @r"
     success: true
     exit_code: 0
     ----- stdout -----
