@@ -1,5 +1,6 @@
 use crate::common::{TestContext, uv_snapshot};
 use anyhow::Result;
+use assert_cmd::assert::OutputAssertExt;
 use assert_fs::fixture::FileTouch;
 use assert_fs::prelude::PathChild;
 
@@ -8,6 +9,7 @@ use uv_static::EnvVars;
 #[test]
 fn python_upgrade() {
     let context: TestContext = TestContext::new_with_versions(&[])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
@@ -30,7 +32,7 @@ fn python_upgrade() {
     ----- stdout -----
 
     ----- stderr -----
-    error: `uv python upgrade` only accepts minor versions
+    error: `uv python upgrade` only accepts minor versions, got: 3.10.17
     ");
 
     // Upgrade patch version
@@ -92,6 +94,7 @@ fn python_upgrade() {
 #[test]
 fn python_upgrade_without_version() {
     let context: TestContext = TestContext::new_with_versions(&[])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
@@ -160,6 +163,7 @@ fn python_upgrade_without_version() {
 #[test]
 fn python_upgrade_transparent_from_venv() {
     let context: TestContext = TestContext::new_with_versions(&["3.13"])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
@@ -262,6 +266,7 @@ fn python_upgrade_transparent_from_venv() {
 #[test]
 fn python_upgrade_transparent_from_venv_preview() {
     let context: TestContext = TestContext::new_with_versions(&["3.13"])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
@@ -325,6 +330,7 @@ fn python_upgrade_transparent_from_venv_preview() {
 #[test]
 fn python_upgrade_ignored_with_python_pin() {
     let context: TestContext = TestContext::new_with_versions(&["3.13"])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
@@ -390,6 +396,7 @@ fn python_upgrade_ignored_with_python_pin() {
 #[test]
 fn python_no_transparent_upgrade_with_venv_patch_specification() {
     let context: TestContext = TestContext::new_with_versions(&["3.13"])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
@@ -455,6 +462,7 @@ fn python_no_transparent_upgrade_with_venv_patch_specification() {
 #[test]
 fn python_transparent_upgrade_venv_venv() {
     let context: TestContext = TestContext::new_with_versions(&["3.13"])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_filtered_virtualenv_bin()
@@ -548,6 +556,7 @@ fn python_transparent_upgrade_venv_venv() {
 #[test]
 fn python_upgrade_transparent_from_venv_module() {
     let context = TestContext::new_with_versions(&["3.13"])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs()
@@ -615,6 +624,7 @@ fn python_upgrade_transparent_from_venv_module() {
 #[test]
 fn python_upgrade_transparent_from_venv_module_in_venv() {
     let context = TestContext::new_with_versions(&["3.13"])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs()
@@ -702,6 +712,7 @@ fn python_upgrade_transparent_from_venv_module_in_venv() {
 #[test]
 fn python_upgrade_force_install() -> Result<()> {
     let context = TestContext::new_with_versions(&["3.13"])
+        .with_python_download_cache()
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_empty_python_install_mirror()
@@ -737,3 +748,27 @@ fn python_upgrade_force_install() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn python_upgrade_implementation() {
+    let context = TestContext::new_with_versions(&[])
+        .with_python_download_cache()
+        .with_filtered_python_keys()
+        .with_filtered_exe_suffix()
+        .with_empty_python_install_mirror()
+        .with_managed_python_dirs();
+
+    // Install pypy
+    context.python_install().arg("pypy@3.11").assert().success();
+
+    // Run the upgrade, we should not install cpython
+    uv_snapshot!(context.filters(), context.python_upgrade(), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    warning: `uv python upgrade` is experimental and may change without warning. Pass `--preview-features python-upgrade` to disable this warning
+    All versions already on latest supported patch release
+    ");
+}
